<!DOCTYPE html>
<html lang="en">
  <head>
    <title>{{type}}</title>
  </head>
  <body>
    <h3>Online documentation</h3>
    <p><a href='http://doc.lubyk.org/{{type}}.html'>doc.lubyk.org/{{type}}.html</a></h1></p>
    
    <h3>Generate</h3>
    <pre>lua scripts/makedoc.lua &amp;&amp; open html/index.html</pre>
  </body>
</html>
